@@ -46,7 +46,7 @@ class Selenium(Scraper):
         options.add_argument("user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.169 Safari/537.36")
         #endregion options
 
-        url = self.config.get(section='SELENIUM', key='url')
+        url = config.get(section='SELENIUM', key='url')
 
         if url is not None:
             self.driver = webdriver.Remote(command_executor=f'{url}', desired_capabilities={'browserName': 'chrome'}, options=options)
